// src/postgres.ts
import { runsOnServer } from "@settlemint/sdk-utils/runtime";
import pg from "pg";
var sleep = (ms) => new Promise((resolve) => setTimeout(resolve, ms));
function setupErrorHandling(pool) {
  let retryCount = 0;
  pool.on("error", async (err) => {
    console.error("[Drizzle] Pool error occurred:", err);
    if (retryCount < 3) {
      retryCount++;
      console.log(`[Drizzle] Attempting to recover - retry ${retryCount}/3`);
      try {
        const client = await pool.connect();
        client.release();
        console.log("[Drizzle] Successfully recovered connection");
        retryCount = 0;
      } catch (retryError) {
        console.error(`[Drizzle] Recovery attempt ${retryCount} failed:`, retryError);
        await sleep(5e3 * 2 ** (retryCount - 1));
      }
    } else {
      console.error("[Drizzle] Max retries exceeded - pool is in an error state");
      pool.emit("permanent-failure", err);
    }
  });
  pool.on("connect", (client) => {
    client.on("error", (err) => {
      console.error("[Drizzle] Database client error:", err);
    });
  });
  pool.on("connect", () => {
    retryCount = 0;
  });
}
function createPostgresPool(databaseUrl) {
  if (!runsOnServer) {
    throw new Error("Drizzle client can only be created on the server side");
  }
  const pool = new pg.Pool({
    connectionString: databaseUrl,
    max: 20,
    idleTimeoutMillis: 3e4,
    connectionTimeoutMillis: 5e3
  });
  setupErrorHandling(pool);
  return pool;
}
export {
  createPostgresPool
};
//# sourceMappingURL=postgres.mjs.map